@@ -187,11 +187,35 @@ class StreamChatAsync(StreamChatInterface):
     async def mark_all_read(self, user_id):
         return await self.post("channels/read", data={"user": {"id": user_id}})
 
+    async def pin_message(self, message_id, user_id, expiration=None):
+        updates = {
+            "set": {
+                "pinned": True,
+                "pin_expires": expiration,
+            }
+        }
+        return await self.update_message_partial(message_id, updates, user_id)
+
+    async def unpin_message(self, message_id, user_id):
+        updates = {
+            "set": {
+                "pinned": False,
+            }
+        }
+        return await self.update_message_partial(message_id, updates, user_id)
+
     async def update_message(self, message):
         if message.get("id") is None:
             raise ValueError("message must have an id")
         return await self.post(f"messages/{message['id']}", data={"message": message})
 
+    async def update_message_partial(self, message_id, updates, user_id, **options):
+        data = updates.copy()
+        if user_id:
+            data["user"] = {"id": user_id}
+        data.update(options)
+        return await self.put(f"messages/{message_id}", data=data)
+
     async def delete_message(self, message_id, **options):
         return await self.delete(f"messages/{message_id}", options)
 
